@@ -1,4 +1,4 @@
-package Pcore::Redis v0.10.0;
+package Pcore::Redis v0.10.1;
 
 use Pcore -dist, -class;
 
@@ -14,8 +14,8 @@ sub run ( $self, $cb ) {
         $cfg = $self->default_config;
 
         # password
-        if ( defined $ENV{REDIS_PASWORD} ) {
-            $cfg->{requirepass} = $ENV{REDIS_PASWORD};
+        if ( defined $ENV{REDIS_PASSWORD} ) {
+            $cfg->{requirepass} = $ENV{REDIS_PASSWORD};
         }
         else {
             $cfg->{requirepass} = P->random->bytes_hex(32);
